@@ -1,13 +1,12 @@
-import requests
+from proxygrab.__utils import AioHttp
 
 
-def proxylist(ptype):
+async def proxylist(ptype: str):
     """Get Proxies from proxy-list.download"""
     url = f"https://www.proxy-list.download/api/v1/get?type={ptype}"
-    r = requests.get(url)
-    if r.status_code == 200:
-        px = r.text
-        px = px.split("\r\n")
+    text, rr = await AioHttp.get_text(url)
+    if rr.status == 200:
+        px = text.split("\r\n")
         proxies = px[1:-2]
         return True, proxies
     return False, "An error occured!\nResponse not equal  200"
